pub enum Hdf5Error {
Show 58 variants
Io(Error),
InvalidFormat(String),
InvalidSignature(Vec<u8>),
UnsupportedVersion(u8, u8),
UnsupportedSuperblockVersion(u8),
InvalidObjectHeader(String),
DatasetNotFound(String),
GroupNotFound(String),
AttributeNotFound(String),
InvalidDatatype(String),
UnsupportedDatatype(String),
TypeConversion {
from: String,
to: String,
},
InvalidDimensions(String),
InvalidShape {
expected: Vec<usize>,
actual: Vec<usize>,
},
InvalidChunkSize(String),
Compression(String),
Decompression(String),
UnsupportedCompressionFilter(String),
ChecksumMismatch {
expected: u32,
actual: u32,
},
InvalidAttributeValue(String),
OutOfBounds {
index: usize,
size: usize,
},
InvalidOffset(String),
InvalidSize(String),
SymbolTable(String),
BTree(String),
Heap(String),
Message(String),
InvalidMessageType(u8),
UnsupportedMessageType(u8),
Layout(String),
UnsupportedLayout(String),
FillValue(String),
FilterPipeline(String),
InvalidFilter(String),
StringEncoding(FromUtf8Error),
InvalidStringPadding(String),
Reference(String),
InvalidReference(String),
Dataspace(String),
InvalidDataspace(String),
UnsupportedDataspace(String),
Selection(String),
Link(String),
InvalidLink(String),
UnsupportedLinkType(String),
ObjectExists(String),
InvalidObjectName(String),
PathNotFound(String),
InvalidPath(String),
ReadOnly,
WriteOnly,
FileAlreadyOpen(String),
FileNotOpen,
FeatureNotAvailable {
feature: String,
},
Internal(String),
Utf8Error(Utf8Error),
TryFromIntError(TryFromIntError),
Core(OxiGdalError),
}Expand description
Comprehensive HDF5 error types
Variants
Io(Error)
I/O error during file operations
InvalidFormat(String)
Invalid HDF5 file format
InvalidSignature(Vec<u8>)
Invalid HDF5 signature (should be \x89HDF\r\n\x1a\n)
UnsupportedVersion(u8, u8)
Unsupported HDF5 version
UnsupportedSuperblockVersion(u8)
Unsupported superblock version
InvalidObjectHeader(String)
Invalid object header
DatasetNotFound(String)
Dataset not found
GroupNotFound(String)
Group not found
AttributeNotFound(String)
Attribute not found
InvalidDatatype(String)
Invalid datatype
UnsupportedDatatype(String)
Unsupported datatype
TypeConversion
Type conversion error
InvalidDimensions(String)
Invalid dimensions
InvalidShape
Invalid shape
InvalidChunkSize(String)
Invalid chunk size
Compression(String)
Compression error
Decompression(String)
Decompression error
UnsupportedCompressionFilter(String)
Unsupported compression filter
ChecksumMismatch
Checksum mismatch
InvalidAttributeValue(String)
Invalid attribute value
OutOfBounds
Out of bounds access
InvalidOffset(String)
Invalid offset
InvalidSize(String)
Invalid size
SymbolTable(String)
Symbol table error
BTree(String)
B-tree error
Heap(String)
Heap error
Message(String)
Message error
InvalidMessageType(u8)
Invalid message type
UnsupportedMessageType(u8)
Unsupported message type
Layout(String)
Layout error
UnsupportedLayout(String)
Unsupported layout
FillValue(String)
Fill value error
FilterPipeline(String)
Filter pipeline error
InvalidFilter(String)
Invalid filter
StringEncoding(FromUtf8Error)
String encoding error
InvalidStringPadding(String)
Invalid string padding
Reference(String)
Reference error
InvalidReference(String)
Invalid reference
Dataspace(String)
Dataspace error
InvalidDataspace(String)
Invalid dataspace
UnsupportedDataspace(String)
Unsupported dataspace
Selection(String)
Selection error
Link(String)
Link error
InvalidLink(String)
Invalid link
UnsupportedLinkType(String)
Unsupported link type
ObjectExists(String)
Object already exists
InvalidObjectName(String)
Invalid object name
PathNotFound(String)
Path not found
InvalidPath(String)
Invalid path
ReadOnly
File is read-only
WriteOnly
File is write-only
FileAlreadyOpen(String)
File already open
FileNotOpen
File not open
FeatureNotAvailable
Feature not available (Pure Rust limitations)
Internal(String)
Internal error (should not happen)
Utf8Error(Utf8Error)
UTF-8 conversion error
TryFromIntError(TryFromIntError)
Integer conversion error
Core(OxiGdalError)
OxiGDAL core error
Implementations
Sourceimpl Hdf5Error
impl Hdf5Error
Sourcepub fn invalid_format(msg: impl Into<String>) -> Self
pub fn invalid_format(msg: impl Into<String>) -> Self
Create an invalid format error
Sourcepub fn invalid_datatype(msg: impl Into<String>) -> Self
pub fn invalid_datatype(msg: impl Into<String>) -> Self
Create an invalid datatype error
Sourcepub fn unsupported_datatype(msg: impl Into<String>) -> Self
pub fn unsupported_datatype(msg: impl Into<String>) -> Self
Create an unsupported datatype error
Sourcepub fn type_conversion(from: impl Into<String>, to: impl Into<String>) -> Self
pub fn type_conversion(from: impl Into<String>, to: impl Into<String>) -> Self
Create a type conversion error
Sourcepub fn invalid_dimensions(msg: impl Into<String>) -> Self
pub fn invalid_dimensions(msg: impl Into<String>) -> Self
Create an invalid dimensions error
Sourcepub fn invalid_shape(expected: Vec<usize>, actual: Vec<usize>) -> Self
pub fn invalid_shape(expected: Vec<usize>, actual: Vec<usize>) -> Self
Create an invalid shape error
Sourcepub fn compression(msg: impl Into<String>) -> Self
pub fn compression(msg: impl Into<String>) -> Self
Create a compression error
Sourcepub fn decompression(msg: impl Into<String>) -> Self
pub fn decompression(msg: impl Into<String>) -> Self
Create a decompression error
Sourcepub fn dataset_not_found(name: impl Into<String>) -> Self
pub fn dataset_not_found(name: impl Into<String>) -> Self
Create a dataset not found error
Sourcepub fn group_not_found(name: impl Into<String>) -> Self
pub fn group_not_found(name: impl Into<String>) -> Self
Create a group not found error
Sourcepub fn attribute_not_found(name: impl Into<String>) -> Self
pub fn attribute_not_found(name: impl Into<String>) -> Self
Create an attribute not found error
Sourcepub fn feature_not_available(feature: impl Into<String>) -> Self
pub fn feature_not_available(feature: impl Into<String>) -> Self
Create a feature not available error
Sourcepub fn code(&self) -> &'static str
pub fn code(&self) -> &'static str
Get the error code for this HDF5 error
Error codes are stable across versions and can be used for documentation and error handling.
Sourcepub fn suggestion(&self) -> Option<&'static str>
pub fn suggestion(&self) -> Option<&'static str>
Get a helpful suggestion for fixing this HDF5 error
Returns a human-readable suggestion that can help users resolve the error.
Sourcepub fn context(&self) -> ErrorContext
pub fn context(&self) -> ErrorContext
Get additional context about this HDF5 error
Returns structured context information including dataset/attribute names and paths.